#
# spec file for package ldb
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitearch:  %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%define talloc_version 2.1.6
%define tdb_version 1.3.8
%define tevent_version 0.9.28

Name:           ldb
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
#!BuildIgnore: libtalloc
BuildRequires:  libtalloc-devel >= %{talloc_version}
BuildRequires:  libtdb-devel >= %{tdb_version}
BuildRequires:  libtevent-devel >= %{tevent_version}
BuildRequires:  libxslt
BuildRequires:  popt-devel
BuildRequires:  pytalloc-devel >= %{talloc_version}
BuildRequires:  python-devel
BuildRequires:  python-tdb >= %{tdb_version}
BuildRequires:  python-tevent >= %{tevent_version}
%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1140
%define	build_make_smp_mflags %{?_smp_mflags}
%else
%define	build_make_smp_mflags %{?jobs:-j%jobs}
%endif
Url:            https://ldb.samba.org/
Version:        1.1.26
Release:        2.4
Summary:        An LDAP-like embedded database
License:        GPL-3.0+
Group:          System/Libraries
Source:         https://download.samba.org/pub/ldb/ldb-%{version}.tar.gz
Source1:        https://download.samba.org/pub/ldb/ldb-%{version}.tar.asc
Source2:        ldb.keyring
Source4:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ldb is an LDAP-like embedded database.


%define libldb_name libldb1
%package -n %{libldb_name}
Summary:        An LDAP-like embedded database
Group:          System/Libraries
PreReq:         /sbin/ldconfig

%description -n %{libldb_name}
Ldb is an LDAP-like embedded database.

This package includes the ldb1 library.


%package -n libldb-devel
Summary:        Libraries and Header Files to Develop Programs with ldb1 Support
Group:          Development/Libraries/C and C++
Requires:       %{libldb_name} = %{version}
%if 0%{?suse_version} > 1020
Requires:       pkg-config
%else
Requires:       pkgconfig
%endif

%description -n libldb-devel
Ldb is an LDAP-like embedded database.

Libraries and Header Files to Develop Programs with ldb1 Support


%package -n ldb-tools
Summary:        Tools to manipulate ldb files
Group:          Development/Libraries/C and C++

%description -n ldb-tools
Tools to manipulate ldb files


%package -n pyldb
Summary:        Python bindings for the LDB library
Group:          Development/Libraries/Python
Provides:       python-ldb = %{version}-%{release}
Requires:       %{libldb_name} = %{version}
PreReq:         /sbin/ldconfig

%description -n pyldb
This package contains the python bindings for the LDB library.


%package -n pyldb-devel
Summary:        Development files for the Python bindings for the LDB library
Group:          Development/Libraries/Python
Provides:       python-ldb-devel = %{version}-%{release}
Requires:       pyldb = %{version}
%if 0%{?suse_version} > 1020
Requires:       pkg-config
%else
Requires:       pkgconfig
%endif

%description -n pyldb-devel
This package contains the development files for the Python bindings for the
LDB library.


%prep
%setup -n ldb-%{version} -q

%build
%if 0%{?suse_version} && 0%{?suse_version} < 911
	OPTIMIZATION="-O"
%else
	# use the default optimization
	unset OPTIMIZATION
%endif
%if 0%{?suse_version} > 1110
	export SUSE_ASNEEDED=0
%endif
export CFLAGS="${RPM_OPT_FLAGS} -D_GNU_SOURCE ${OPTIMIZATION} -D_LARGEFILE64_SOURCE -DIDMAP_RID_SUPPORT_TRUSTED_DOMAINS"
CONFIGURE_OPTIONS="\
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--disable-rpath \
	--disable-rpath-install \
	--disable-silent-rules \
	--with-modulesdir=%{_libdir} \
	--bundled-libraries=NONE \
	--builtin-libraries=replace \
"
./configure ${CONFIGURE_OPTIONS}
%{__make} %{build_make_smp_mflags} \
	all
doxygen Doxyfile
# remove man page with bogus full build dir in path
rm -f apidocs/man/man3/_*_ldb-%{version}_include_.3

%check
%ifnarch ppc64 s390x
LD_LIBRARY_PATH="bin/shared:bin/shared/private" \
LDB_MODULES_PATH="bin/modules" \
%{__make} test
%endif

%install
DESTDIR=${RPM_BUILD_ROOT} make install

# Install API documentation
cp -a apidocs/man/* $RPM_BUILD_ROOT/%{_mandir}

%post -n %{libldb_name} -p /sbin/ldconfig

%postun -n %{libldb_name} -p /sbin/ldconfig

%post -n pyldb -p /sbin/ldconfig

%postun -n pyldb -p /sbin/ldconfig

%files -n %{libldb_name}
%defattr(-,root,root)
%{_libdir}/libldb.so.*
%dir %{_libdir}/ldb
%{_libdir}/ldb/asq.so
%{_libdir}/ldb/paged_results.so
%{_libdir}/ldb/paged_searches.so
%{_libdir}/ldb/rdn_name.so
%{_libdir}/ldb/sample.so
%{_libdir}/ldb/server_sort.so
%{_libdir}/ldb/skel.so
%{_libdir}/ldb/tdb.so

%files -n libldb-devel
%defattr(-,root,root)
%{_includedir}/ldb.h
%{_includedir}/ldb_errors.h
%{_includedir}/ldb_handlers.h
%{_includedir}/ldb_module.h
%{_includedir}/ldb_version.h
%{_libdir}/libldb.so
%dir %{_libdir}/ldb
%{_libdir}/pkgconfig/ldb.pc
%{_mandir}/man3/ldb*.3.*
%if 0%{?suse_version} != 1110
%{_mandir}/man3/ldif*.3.*
%endif

%files -n ldb-tools
%defattr(-,root,root)
%{_bindir}/ldbadd
%{_bindir}/ldbdel
%{_bindir}/ldbedit
%{_bindir}/ldbmodify
%{_bindir}/ldbrename
%{_bindir}/ldbsearch
%{_libdir}/ldb/libldb-cmdline.so
%{_mandir}/man1/ldbadd.1.*
%{_mandir}/man1/ldbdel.1.*
%{_mandir}/man1/ldbedit.1.*
%{_mandir}/man1/ldbmodify.1.*
%{_mandir}/man1/ldbrename.1.*
%{_mandir}/man1/ldbsearch.1.*

%files -n pyldb
%defattr(-,root,root)
%{python_sitearch}/ldb.so
%{python_sitearch}/_ldb_text.py*
%{_libdir}/libpyldb-util.so.*

%files -n pyldb-devel
%defattr(-,root,root)
%{_includedir}/pyldb.h
%{_libdir}/libpyldb-util.so
%{_libdir}/pkgconfig/pyldb-util.pc
%if 0%{?suse_version} != 1110
%{_mandir}/man3/PyLdb*.3.*
%endif

%changelog
* Tue Mar 15 2016 lmuelle@suse.com
- Require talloc 2.1.6 at build-time; (bsc#954658).
* Wed Feb 17 2016 lmuelle@suse.com
- Update to 1.1.26; (bsc#954658).
  + let a timeout of -1 indicate no timeout for a given request
  + fix memory leaks in pyldb ldb.search()
  + build fixes
  + improve pyldb ldb.search() help message
  + add pyldb ldb.search_iterator() api
  + add LDB_ATTR_FLAG_FORCE_BASE64_LDIF as optional argument
    to ldb_schema_attribute_add()
  + add client support for LDB_CONTROL_DIRSYNC_EX
* Fri Feb 12 2016 lmuelle@suse.com
- Provide python-ldb and python-ldb-devel; (bsc#966523).
* Wed Jan 27 2016 lmuelle@suse.com
- Update to 1.1.25; (bsc#954658).
  + torture: test ldb_unpack_data_only_attr_list
  + increment version due to added ldb_unpack_data_only_attr_list
  + introduce ldb_unpack_data_withlist to unpack partial list of attributes
* Thu Dec 10 2015 lmuelle@suse.com
- Update to 1.1.24.
  + fix LDAP \00 search expression attack DoS; CVE-2015-3223; (bso#11325)
  + fix remote read memory exploit in LDB; CVE-2015-5330; (bso#11599)
  + move ldb_(un)pack_data into ldb_module.h for testing
  + fix installation of _ldb_text.py
  + fix propagation of LDB errors through TDB
  + fix bug triggered by having an empty message in database during search
* Wed Nov 11 2015 lmuelle@suse.com
- Update to 1.1.23; (bsc#954658).
  + Test improvements
  + Minor build fixes
* Fri Oct 30 2015 lmuelle@suse.com
- Add doxygen at build time to add the development documentation.
- Disable rpath-install and silent-rules while configure.
* Mon Sep  7 2015 lmuelle@suse.com
- Move the ldb-cmdline library to the ldb-tools package as the packaged
  binaries depend on it.
* Mon Sep  7 2015 lmuelle@suse.com
- Update the Samba Library Distribution Key file 'ldb.keyring'; (bso#945116).
* Wed Jul 22 2015 lmuelle@suse.com
- Update to 1.1.21; (bsc#939050).
  + build fixes
  + improved python bindings
* Sun Mar  1 2015 lmuelle@suse.com
- Update to 1.1.20.
  + validate_ldb of String(Generalized-Time) does not accept millisecond
    format ".000Z"; (bso#9810)
  + fix logic in ldb_val_to_time()
* Tue Jan 13 2015 lmuelle@suse.com
- Update to 1.1.19.
  + Allow to register extended match rules
* Sun Dec 21 2014 lmuelle@suse.com
- Update to 1.1.18.
  + fixes for segfaults in pyldb
  + documentation fixes
  + build system improvements
  + fix a typo in the comment, LDB_FLAGS_MOD_xxx -> LDB_FLAG_MOD_xxx
  + Fix check for third_party
  + make the successful ldb_transaction_start() message clearer
  + ldb-samba: fix a memory leak in ldif_canonicalise_objectCategory()
  + ldb-samba: Move pyldb-utils dependency to python_samba__ldb
  + build: improve detection of srcdir
* Thu Nov  6 2014 lmuelle@suse.com
- Use the upstream tar ball, as signature verification is now able to handle
  compressed archives.
* Tue Oct 28 2014 lmuelle@suse.com
- Remove dependency on gpg-offline as signature checking is implemented in the
  source validator.
* Tue Sep 23 2014 lmuelle@suse.com
- BuildRequire docbook-xsl-stylesheets and libxslt to process the man pages.
* Fri May 23 2014 lmuelle@suse.com
- Require pkg-config from the devel sub packages and do not BuildRequire it
  from libldb.
* Mon May  5 2014 lmuelle@suse.com
- Update to 1.1.17.
  + pyldb: add some more helper functions for LdbDn
  + pyldb: fix doc string for set_extended_component()
  + pyldb: add some const to PyObject_FromLdbValue()
  + Add a env variable to disable RTLD_DEEPBIND.
  + ldb_ildap: Map some wrong username/password errors on to
    LDB_ERR_INVALID_CREDENTIALS
  + pass module init errors back to the caller
  + Return LDB_ERR_INSUFFICIENT_ACCESS_RIGHTS rather than OPERATIONS_ERROR on
    EACCES and EPERM
  + Fix 1138330 Dereference null return value
  + bad if test in ldb_comparison_fold()
  + use of NULL pointer bugfix
  + Fix CID 241329 Array compared against 0
  + Fix CID 240798 Uninitialized pointer read
  + rdn_name: reject 'distinguishedName' depending of the MOD flags
  + Show the type of failing operation in default error message
  + Do not build libldb-cmdline when using system ldb.
  + ldb_map: Fix CID 1034791 Dereference null return value
  + Fix a const warning
* Fri Dec  6 2013 lmuelle@suse.com
- Verify source tar ball gpg signature.
* Thu Aug 29 2013 lmuelle@suse.com
- Consolidate python files in independent pyldb subpackages.
- Add pyldb to baselibs.conf.
* Tue Jul  2 2013 lmuelle@suse.com
- Update to 1.1.16.
  + Bump version to allow a depencency on the substring crash fix.
  + Cope with substring match with no chunks in ldb_filter_from_tree().
  + Ensure not to segfault on a filter such as (mail=).
  + Add missing dependency on replace for ldb.
  + Add more data test data for one level test cases.
  + Add tests for the python api.
  + Add more tests related to onelevel search.
  + Use strncmp instead of strcmp when comparing the val part.
  + Make test output more readable.
* Wed Feb  6 2013 lmuelle@suse.com
- Update to 1.1.15.
  + Ensure to decrement the transaction_active whenever we delete
    a transaction.
  + Move doxygen comments for ldb_connect to the right place.
* Sun Dec  2 2012 lmuelle@suse.com
- Update to 1.1.14.
  + fixed callers for ldb_pack_data() and ldb_unpack_data()
  + move ldb_pack.c into common
  + Add ldbdump, based on tdbdump
  + Remove no-longer-existing ltdb_unpack_data_free from ldb_tdb.h
  + Change ltdb_unpack_data to take an ldb_context
- Update to 1.1.13.
  + Don't use "isprint" in ldb_binary_encode(); (bso#9147).
* Mon Sep  3 2012 lmuelle@suse.com
- Update to 1.1.12.
  + Avoid printing secret attributes in ldb trace logs
* Thu Aug 30 2012 lmuelle@suse.com
- Update to 1.1.11.
  + LDB:ldb_tdb.c - deny multi-valued attributes manipulation with doublets
  + LDB:ldbsearch - add search filter tests
  + LDB:ldbsearch - search filters do not only contain "="
  + lib/ldb: Use tdb_parse_record and a callback rather than tdb_fetch()
- BuildRequire tevent version >= 0.9.17.
* Thu Aug 16 2012 lmuelle@suse.com
- Remove superfluous ldb-tools rpmlintrc file.
* Thu Aug  9 2012 lmuelle@suse.com
- Update to 1.1.10.
  + Enhancements and fixes to the s3 read, sesssetup, and server functions
  + s3: Fix a crash in reply_lockingX_error
  + s3:libsmb, smbd, and s4:libcli: add EXTENDED_SIGNATURE support in tcon
  + s3:rpc_server: make usage of session_extract_session_key()
  + s3:smb2_*: make use of SMBD_SMB2_*()
  + s4 and libcli: enahncements and fixes
* Tue Aug  7 2012 lmuelle@suse.com
- Update to 1.1.9.
  + Ensure rename target does not exist before deleting old record.
  + Add parameter to avoid NULL format string flagged by -Werror=format.
- Update to 1.1.8.
  + Fixes for pyldb.
  + Drop support for tdb_compat.
- BuildRequire pytalloc-devel.
* Thu Jun 28 2012 lmuelle@suse.com
- Disable rpath while configure.
* Wed Jun 13 2012 ddiss@suse.com
- Tag GPL-3.0+ based on tdb license; (bnc#765270).
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libldb1.
* Sun Jun  3 2012 lmuelle@suse.com
- Add missing post, postun, and files part to the libldb1 package.
* Sat Jun  2 2012 lmuelle@suse.com
- Rename package to ldb and add an independent libldb1 subpackage.
- Enhance and polish the package descriptions and summaries.
* Fri Jun  1 2012 lmuelle@suse.com
- BuildIgnore libtalloc to prevent a package conflict on Fedora systems.
* Fri Jun  1 2012 lmuelle@suse.com
- BuildRequire popt-devel.
* Thu May 31 2012 lmuelle@suse.com
- Define and use talloc, tdb, and tevent version macros.
- Define python_sitearch if undefined.
* Thu May 31 2012 lmuelle@suse.com
- BuildRequire libtalloc-devel, libtdb-devel, and libtevent-devel.
- Configure with bundled tdb2 library.
* Fri May 25 2012 lmuelle@suse.com
- Cleanup BuildRequires and spec file in general.
* Thu May 17 2012 lmuelle@suse.com
- BuildRequire libtalloc2-devel >= 2.0.7.
* Mon May 14 2012 lmuelle@suse.com
- BuildRequire libtalloc2-devel, libtdb1-devel, and libtevent0-devel.
- Adjust license string.
- Require libldb1 = %%{version} from the devel package.
* Wed Sep  7 2011 lars@samba.org
- Initial independent libldb1 package.
